
Single input validation controls
-------

**Description:**

Input validation refers to the process of validating all the input to an application
before using it. Input validation is absolutely critical to application security, 
and most application risks involve tainted input at some level.

**Solution:**

Verify that a single input validation control is used by the application for each 
type of data that is accepted. This way your validation controls stay clear, transpirant
and manageable. This method leaves less room for error.

Recomended knowledge base items:

- Positive validation method
- Input validation
- Input rejection
- Client side input validation
- Character encoding
